@@ -65,6 +65,7 @@ namespace Tomboy
 
 			TomboyCommandLine cmd_line = new TomboyCommandLine (args);
 			debugging = cmd_line.Debug;
+			Logger.LogLevel = debugging ? Level.DEBUG : Level.INFO;
 			is_panel_applet = cmd_line.UsePanelApplet;
 
 #if ENABLE_DBUS || WIN32 || MAC // Run command-line earlier with DBus enabled
@@ -299,9 +300,7 @@ namespace Tomboy
 				tray_icon.GetGeometry (out screen, out area, out orientation);
 #endif
 			}
-			GuiUtils.ShowHelp("tomboy.xml", null,
-			                  screen,
-			                  null);
+			GuiUtils.ShowHelp ("ghelp:tomboy", screen, null);
 
 		}
 
@@ -343,7 +342,7 @@ namespace Tomboy
 			                                    "note-taking application.");
 			Gtk.AboutDialog.SetUrlHook (delegate (Gtk.AboutDialog dialog, string link) {
 				try {
-					Services.NativeApplication.OpenUrl (link);
+					Services.NativeApplication.OpenUrl (link, null);
 				} catch (Exception e) {
 					GuiUtils.ShowOpeningLocationError (dialog, link, e.Message);
 				}
